@@ -159,7 +159,7 @@ BIFIE.pathmodel <- function( BIFIEobj, lavaan.model, reliability=NULL,
 
     wgt_ <- matrix( wgt, ncol=1 )
     if ( is.null( group) ){ nogroup <- TRUE } else { nogroup <- FALSE }
-    cat(paste0( "|", paste0( rep("*", FF), collapse=""), "|\n" ))
+    prepareConsoleProgressBar(FF)
     if (nogroup){
         group <- "one"
         group_values <- c(1)
