@@ -1,13 +1,13 @@
 ## File Name: BIFIE_lavaan_survey_extract_dataset.R
-## File Version: 0.08
+## File Version: 0.091
 
 BIFIE_lavaan_survey_extract_dataset <- function(svyrepdes, ii, variables,
     svyrepdes0=NULL, datalist=NULL)
 {
-    if ( class(svyrepdes)=="svyimputationList"){
+    if ( inherits(svyrepdes,"svyimputationList") ){
         svyrepdes0 <- svyrepdes$designs[[ii]]
     }
-    if ( class(svyrepdes)=="BIFIEdata"){
+    if ( inherits(svyrepdes,"BIFIEdata") ){
         use_datalist <- (ii>1) & ( ! is.null(datalist) )
         if (! use_datalist){
             svyrepdes0 <- BIFIEdata2svrepdesign(bifieobj=svyrepdes, varnames=variables,
