@@ -8,11 +8,15 @@
 # on attach
 .onAttach <- function(libname,pkgname)
 {
+    if (getOption("BIFIEsurvey.quiet", default = FALSE)) {
+      return()
+    }
+  
     d <- utils::packageDescription("BIFIEsurvey")
     packageStartupMessage("|---------------------------------------------------------",
                 "--------\n",
                 paste("| ",d$Package," ", d$Version," (",d$Date,")",sep=""),
-                "\n| http://www.bifie.at                                             ",
+                "\n| http://www.iqs.gv.at                                             ",
                 "\n|---------------------------------------------------",
                 "--------------\n" )
 }
@@ -23,3 +27,11 @@ version <- function(pkg="BIFIEsurvey")
     d <- utils::packageDescription(pkg)
     return( paste(d$Package,d$Version,d$Date,lib) )
 }
+
+prepareConsoleProgressBar <- function(numberOfImputations) {
+  if (getOption("BIFIEsurvey.quiet", default = FALSE)) {
+    return()
+  }
+  
+  cat(paste0( "|", paste0( rep("*", numberOfImputations), collapse=""), "|\n" ))
+}
